@@ -31,6 +31,19 @@ from eventlet.green import socket
 from oslo_service._i18n import _
 from oslo_service import _options
 
+from debtcollector import removals
+
+removals.removed_module(
+    __name__,
+    replacement=None,
+    removal_version="2026.2",
+    message=(
+        "The 'eventlet_backdoor' module is deprecated and will be removed in "
+        "version 2026.2. This module is not being replaced. Please migrate "
+        "away from using it and remove any dependencies on this module."
+    )
+)
+
 
 LOG = logging.getLogger(__name__)
 
@@ -40,7 +53,7 @@ class EventletBackdoorConfigValueError(Exception):
         msg = (_('Invalid backdoor_port configuration %(range)s: %(ex)s. '
                '%(help)s') %
                {'range': port_range, 'ex': ex, 'help': help_msg})
-        super(EventletBackdoorConfigValueError, self).__init__(msg)
+        super().__init__(msg)
         self.port_range = port_range
 
 
@@ -50,7 +63,7 @@ def _dont_use_this():
 
 def _dump_frame(f, frame_chapter):
     co = f.f_code
-    print(" %s Frame: %s" % (frame_chapter, co.co_name))
+    print(f" {frame_chapter} Frame: {co.co_name}")
     print("     File: %s" % (co.co_filename))
     print("     Captured at line number: %s" % (f.f_lineno))
     co_locals = set(co.co_varnames)
@@ -64,7 +77,8 @@ def _dump_frame(f, frame_chapter):
         if set_locals:
             print("     %s set local variables:" % (len(set_locals)))
             for var_name in sorted(set_locals.keys()):
-                print("       %s => %r" % (var_name, f.f_locals[var_name]))
+                print("       {} => {!r}".format(
+                    var_name, f.f_locals[var_name]))
         else:
             print("     0 set local variables.")
         if not_set:
@@ -80,13 +94,14 @@ def _dump_frame(f, frame_chapter):
 def _detailed_dump_frames(f, thread_index):
     i = 0
     while f is not None:
-        _dump_frame(f, "%s.%s" % (thread_index, i + 1))
+        _dump_frame(f, f"{thread_index}.{i + 1}")
         f = f.f_back
         i += 1
 
 
 def _find_objects(t):
-    return [o for o in gc.get_objects() if isinstance(o, t)]
+    return [o for o in gc.get_objects()
+            if hasattr(o, "__class__") and isinstance(o, t)]
 
 
 def _capture_profile(fname=''):
@@ -163,7 +178,7 @@ def _listen(host, start_port, end_port):
     while True:
         try:
             return _listen_func(host, try_port)
-        except socket.error as exc:
+        except OSError as exc:
             if (exc.errno != errno.EADDRINUSE or
                try_port >= end_port):
                 raise
@@ -173,7 +188,7 @@ def _listen(host, start_port, end_port):
 def _try_open_unix_domain_socket(socket_path):
     try:
         return eventlet.listen(socket_path, socket.AF_UNIX)
-    except socket.error as e:
+    except OSError as e:
         if e.errno != errno.EADDRINUSE:
             # NOTE(harlowja): Some other non-address in use error
             # occurred, since we aren't handling those, re-raise
@@ -217,9 +232,8 @@ def _initialize_if_enabled(conf):
         except (KeyError, IndexError, ValueError) as e:
             backdoor_socket_path = conf.backdoor_socket
             LOG.warning("Could not apply format string to eventlet "
-                        "backdoor socket path ({}) - continuing with "
-                        "unformatted path"
-                        "".format(e))
+                        "backdoor socket path (%s) - continuing with "
+                        "unformatted path", e)
         sock = _try_open_unix_domain_socket(backdoor_socket_path)
         where_running = backdoor_socket_path
 
@@ -255,12 +269,6 @@ def initialize_if_enabled(conf):
 def _main():
     import eventlet
     eventlet.monkey_patch(all=True)
-    # Monkey patch the original current_thread to use the up-to-date _active
-    # global variable. See https://bugs.launchpad.net/bugs/1863021 and
-    # https://github.com/eventlet/eventlet/issues/592
-    import __original_module_threading as orig_threading
-    import threading  # noqa
-    orig_threading.current_thread.__globals__['_active'] = threading._active
 
     from oslo_config import cfg
 
