@@ -21,6 +21,7 @@ import multiprocessing
 import os
 import signal
 import socket
+import subprocess
 import time
 import traceback
 from unittest import mock
@@ -160,19 +161,21 @@ class ServiceLauncherTest(ServiceTestBase):
         return workers
 
     def _get_workers(self):
-        f = os.popen('ps ax -o pid,ppid,command')
+        proc = subprocess.Popen(
+            ['ps', 'ax', '-o', 'pid,ppid,command'],
+            stdout=subprocess.PIPE, encoding='utf-8')
         # Skip ps header
-        f.readline()
+        proc.stdout.readline()
 
         processes = [tuple(int(p) for p in line.strip().split()[:2])
-                     for line in f]
+                     for line in proc.stdout]
         return [p for p, pp in processes if pp == self.pid]
 
     def test_killed_worker_recover(self):
         start_workers = self._spawn()
 
         # kill one worker and check if new worker can come up
-        LOG.info('pid of first child is %s' % start_workers[0])
+        LOG.info('pid of first child is %r', start_workers[0])
         os.kill(start_workers[0], signal.SIGTERM)
 
         # Wait at most 5 seconds to respawn a worker
@@ -182,7 +185,7 @@ class ServiceLauncherTest(ServiceTestBase):
 
         # Make sure worker pids don't match
         end_workers = self._get_workers()
-        LOG.info('workers: %r' % end_workers)
+        LOG.info('workers: %r', end_workers)
         self.assertNotEqual(start_workers, end_workers)
 
     def _terminate_with_signal(self, sig):
@@ -196,7 +199,7 @@ class ServiceLauncherTest(ServiceTestBase):
         self._wait(cond, timeout)
 
         workers = self._get_workers()
-        LOG.info('workers: %r' % workers)
+        LOG.info('workers: %r', workers)
         self.assertFalse(workers, 'No OS processes left.')
 
     def test_terminate_sigkill(self):
@@ -229,7 +232,7 @@ class ServiceLauncherTest(ServiceTestBase):
 
         # Make sure worker pids match
         end_workers = self._get_workers()
-        LOG.info('workers: %r' % end_workers)
+        LOG.info('workers: %r', end_workers)
         self.assertEqual(start_workers, end_workers)
 
     def test_parent_signal_sighup(self):
@@ -424,6 +427,16 @@ class LauncherTest(base.ServiceBaseTestCase):
         serv = FooService()
         self.assertRaises(TypeError, launcher.launch_service, serv)
 
+    def test_no_fork(self):
+        with mock.patch(
+                'oslo_service.service.ServiceLauncher.launch_service'
+        ) as mock_launch:
+            svc = service.Service()
+            service.launch(
+                self.conf, svc,
+                workers=1, restart_method="reload", no_fork=True)
+            mock_launch.assert_called_with(svc, workers=1)
+
 
 class ProcessLauncherTest(base.ServiceBaseTestCase):
 
@@ -638,10 +651,14 @@ class EventletServerProcessLauncherTest(base.ServiceBaseTestCase):
         # NOTE(bnemec): process_time of 5 needs to be longer than the graceful
         # shutdown timeout in the "exceeded" test below, but also needs to be
         # shorter than the timeout in the regular graceful shutdown test.
+        kwargs = {'workers': self.workers, 'process_time': 5}
+        # graceful_shutdown_timeout is registered in
+        # ServiceBaseTestCase.setUp()
+        kwargs['graceful_shutdown_timeout'] = (
+            self.conf.graceful_shutdown_timeout)
         proc = multiprocessing.Process(target=eventlet_service.run,
                                        args=(queue,),
-                                       kwargs={'workers': self.workers,
-                                               'process_time': 5})
+                                       kwargs=kwargs)
         proc.start()
 
         port = queue.get()
@@ -692,15 +709,18 @@ class EventletServerProcessLauncherTest(base.ServiceBaseTestCase):
 
     def test_graceful_stop_with_exceeded_graceful_shutdown_timeout(self):
         # Server must exit if graceful_shutdown_timeout exceeded
-        graceful_shutdown_timeout = 4
+        graceful_shutdown_timeout = 2
         self.config(graceful_shutdown_timeout=graceful_shutdown_timeout)
         proc, conn = self.run_server()
 
         time_before = time.time()
         os.kill(proc.pid, signal.SIGTERM)
         self.assertTrue(proc.is_alive())
+        # If graceful_shutdown_timeout works, the process should exit.
+        # If it doesn't work, the test will hang which is a useful signal.
         proc.join()
-        self.assertFalse(proc.is_alive())
+        self.assertFalse(proc.is_alive(),
+                         "Process should have exited after graceful timeout")
         time_after = time.time()
 
         self.assertTrue(time_after - time_before > graceful_shutdown_timeout)
